==> apache-camel-3.10.0-src.zip: apache-camel-3.10.0/components/camel-soroush/src/test/java/org/apache/camel/component/soroushbot/support/SoroushMockServer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.soroushbot.support;

import org.eclipse.jetty.server.Server;
import org.eclipse.jetty.servlet.ServletContextHandler;
import org.eclipse.jetty.servlet.ServletHolder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SoroushMockServer extends Thread {
    private static final Logger LOG = LoggerFactory.getLogger(SoroushMockServer.class);

    private Server jettyServer;
    private Integer port = 8080;

    @Override
    public void start() {
        ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
        context.setContextPath("/");

        if (port == null) {
            port = 0;
        }
        jettyServer = new Server(port);

        jettyServer.setHandler(context);

        ServletHolder jerseyServlet = context.addServlet(
                org.glassfish.jersey.servlet.ServletContainer.class, "/*");
        jerseyServlet.setInitOrder(0);

        // Tells the Jersey Servlet which REST service/class to load.
        jerseyServlet.setInitParameter(
                "jersey.config.server.provider.classnames",
                SoroushBotWS.class.getCanonicalName());
        jerseyServlet.setInitParameter("javax.ws.rs.Application", SoroushBotApplication.class.getCanonicalName());
        if (!jettyServer.isStarted()) {
            try {
                jettyServer.start();
                port = jettyServer.getURI().getPort();
            } catch (Exception e) {
                LOG.warn("Failed to start the Jetty server: {}", e.getMessage(), e);
            }
        }
    }

    public Integer getPort() {
        return port;
    }

    public void setPort(Integer port) {
        this.port = port;
    }
}

==> apache-camel-3.14.3-src.zip: apache-camel-3.14.3/components/camel-soroush/src/test/java/org/apache/camel/component/soroushbot/support/SoroushMockServer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.soroushbot.support;

import org.apache.camel.test.AvailablePortFinder;
import org.eclipse.jetty.server.Server;
import org.eclipse.jetty.servlet.ServletContextHandler;
import org.eclipse.jetty.servlet.ServletHolder;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SoroushMockServer extends Thread {
    private static final Logger LOG = LoggerFactory.getLogger(SoroushMockServer.class);

    private Server jettyServer;
    private Integer port = AvailablePortFinder.getNextAvailable();

    @Override
    public void start() {
        ServletContextHandler context = new ServletContextHandler(ServletContextHandler.SESSIONS);
        context.setContextPath("/");

        if (port == null) {
            port = 0;
        }
        jettyServer = new Server(port);

        jettyServer.setHandler(context);

        ServletHolder jerseyServlet = context.addServlet(
                org.glassfish.jersey.servlet.ServletContainer.class, "/*");
        jerseyServlet.setInitOrder(0);

        // Tells the Jersey Servlet which REST service/class to load.
        jerseyServlet.setInitParameter(
                "jersey.config.server.provider.classnames",
                SoroushBotWS.class.getCanonicalName());
        jerseyServlet.setInitParameter("javax.ws.rs.Application", SoroushBotApplication.class.getCanonicalName());
        if (!jettyServer.isStarted()) {
            try {
                jettyServer.start();
                port = jettyServer.getURI().getPort();
            } catch (Exception e) {
                LOG.warn("Failed to start the Jetty server: {}", e.getMessage(), e);
            }
        }
    }

    public Integer getPort() {
        return port;
    }

    public void setPort(Integer port) {
        this.port = port;
    }
}
